# Blueprint

A maneira mais simples e poderosa de gerar código boilerplate universal.

## Installation

Instale via pip:

```bash
pip install blprint
```

## Setup

1. Crie uma pasta chamada `blueprints` na raiz do seu projeto.
2. Dentro dela, crie uma subpasta nomeada conforme o que você está desenvolvendo.
3. Adicione um template Jinja2 nessa subpasta com o código boilerplate desejado.

## Usage

Gere seu blueprint executando:

```bash
blueprint create <blueprint_name> <destination>
```
